# Con, like git, but in French - Con, comme git, mais en français

Con is a French wrapper around the git toolbox, inspired by the amazing tool [Marcel](https://github.com/brouberol/marcel).

## Examples

* ``git push`` → ``con pulse``
* ``git pull`` → ``con tracte``
* ``git merge`` → ``con bine``

## Naming origin

The name "[con](https://www.wordreference.com/enfr/git)" is an approximate translation for "[git](https://en.wiktionary.org/wiki/git#Translations)".

For example, in French, one can say: "Tu es con, ou quoi ?"

In some local dialects, like in Marseille, it's used as a punctuation word, like in the sentence:
"Hé! Tu n'aurais pas oublié le frein à main, con ?"

# Installation

```shell
pip install con-wrapper
```

# Current status

Con is not currently developed, but shall soon be available.

# Thanks

Many thanks to:

- [Balthazar Rouberol](https://github.com/brouberol) for creating [Marcel](https://github.com/brouberol/marcel)
- Everyone in [this thread](https://github.com/moby/moby/issues/19396) for their great ideas
- [Valentin Pichard](https://github.com/w3st3ry) for his alternative wrapper [guitte](https://github.com/w3st3ry/guitte)
